@@ -13,14 +13,20 @@ common::sense - save a tree AND a kitten, use common::sense!
  # use strict qw(vars subs);
  # use feature qw(say state switch);
  # no warnings;
- # use warnings qw(FATAL closed threads internal debugging pack malloc
- #                 portable prototype inplace io pipe unpack regexp
- #                 deprecated exiting glob digit printf layer
+ # use warnings qw(FATAL closed threads internal debugging pack
+ #                 portable prototype inplace io pipe unpack malloc
+ #                 deprecated glob digit printf layer
  #                 reserved taint closure semicolon);
  # no warnings qw(exec newline unopened);
 
+
 =head1 DESCRIPTION
 
+   “Nothing is more fairly distributed than common sense: no one thinks
+   he needs more of it than he already has.”
+
+   – René Descartes
+
 This module implements some sane defaults for Perl programs, as defined by
 two typical (or not so typical - use your common sense) specimens of Perl
 coders. In fact, after working out details on which warnings and strict
@@ -54,6 +60,12 @@ warnings are fatal by default.
 
 =back
 
+Unfortunately, there is no fine-grained warning control in perl, so often
+whole groups of useful warnings had to be excluded because of a single
+useless warning (for example, perl puts an arbitrary limit on the length
+of text you can match with some regexes before emitting a warning, making
+the whole C<regexp> category useless).
+
 What follows is a more thorough discussion of what this module does,
 and why it does it, and what the advantages (and disadvantages) of this
 approach are.
@@ -216,13 +228,13 @@ often be modules that pull in the monster pragmas. But one can hope...
 
 package common::sense;
 
-our $VERSION = '3.2';
+our $VERSION = '3.4';
 
 # overload should be included
 
 sub import {
    # use warnings
-   ${^WARNING_BITS} ^= ${^WARNING_BITS} ^ "\xfc\x3f\x33\x00\x0f\xf3\x0f\xc0\xf0\xfc\x33\x00";
+   ${^WARNING_BITS} ^= ${^WARNING_BITS} ^ "\x3c\x3f\x33\x00\x0f\xf0\x0f\xc0\xf0\xfc\x33\x00";
    # use strict, use utf8;
    $^H |= 0x800600;
    # use feature
@@ -388,7 +400,7 @@ experienced Perl programmers, not people migrating from other languages
 who might be surprised about stuff such as C<undef>. On the other hand,
 this does not exclude the usefulness of this module for total newbies, due
 to its strictness in enforcing policy, while at the same time not limiting
-the expresive power of perl.
+the expressive power of perl.
 
 This module is considerably I<more> strict than the canonical C<use
 strict; use warnings>, as it makes all its warnings fatal in nature, so
